@@ -1,6 +1,6 @@
 // This may look like C code, but it is really -*- C++ -*-
 //
-// Copyright Bob Friesenhahn, 1999, 2000, 2001, 2002, 2003, 2004
+// Copyright Bob Friesenhahn, 1999, 2000, 2001, 2002, 2003, 2004, 2009
 //
 // Definition and implementation of template functions for using
 // Magick::Image with STL containers.
@@ -207,6 +207,37 @@ namespace Magick
     Color _penColor;
   };
 
+  // Bake in the ASC-CDL, which is a convention for the for the
+  // exchange of basic primary color grading information between for
+  // the exchange of basic primary color grading information between
+  // equipment and software from different manufacturers.  It is a
+  // useful transform for other purposes as well.
+  class MagickDLLDecl cdlImage : public std::unary_function<Image&,void>
+  {
+  public:
+    cdlImage( const std::string &cdl_ );
+
+    void operator()( Image &image_ ) const;
+
+  private:
+    std::string   _cdl;
+  };
+
+  // Apply a color matrix to the image channels.  The user supplied
+  // matrix may be of order 1 to 5 (1x1 through 5x5).
+  class MagickDLLDecl colorMatrixImage : public std::unary_function<Image&,void>
+  {
+  public:
+    colorMatrixImage( const unsigned int order_,
+		      const double *color_matrix_ );
+
+    void operator()( Image &image_ ) const;
+
+  private:
+    unsigned int  _order;
+    const double *_color_matrix;
+  };
+
   // Convert the image colorspace representation
   class MagickDLLDecl colorSpaceImage : public std::unary_function<Image&,void>
   {
@@ -534,6 +565,18 @@ namespace Magick
     double _factor;
   };
 
+  // Apply a color lookup table (Hald CLUT) to the image.
+  class MagickDLLDecl haldClutImage : public std::unary_function<Image&,void>
+  {
+  public:
+    haldClutImage( const Image &haldClutImage_ );
+    
+    void operator()( Image &image_ ) const;
+
+  private:
+    Image             _haldClutImage;
+  };
+
   // Set image validity. Valid images become empty (inValid) if
   // argument is false.
   class MagickDLLDecl isValidImage : public std::unary_function<Image&,void>
@@ -865,14 +908,16 @@ namespace Magick
   class MagickDLLDecl shadeImage : public std::unary_function<Image&,void>
   {
   public:
-    shadeImage( const double clusterThreshold_ = 1.0, 
-		const double smoothingThreshold_ = 1.5 );
+    shadeImage( const double azimuth_ = 30,
+		const double elevation_ = 30,
+		const bool   colorShading_ = false );
 
     void operator()( Image &image_ ) const;
 
   private:
-    double  _clusterThreshold;
-    double  _smoothingThreshold;
+    double  _azimuth;
+    double  _elevation;
+    bool    _colorShading;
   };
 
   // Sharpen pixels in image
